Changelog
=========

0.1.21
------

- Add support for handlers start and stop;

0.1.19 - 0.1.20
---------------

- Add support for worker restarting after their ttl expired;

0.1.17 - 0.1.18
---------------

- Ensure that acceptors started after workers crashed;

0.1.15 - 0.1.16
---------------

- Fix bugs;

0.1.14
------

- Start listeners after workers;

0.1.1 - 0.1.13
--------------

- Add support for prefork model;

0.1.0 (initial release)
-----------------------

- Base prototype;
